function pieChart() {
    var chartSizePercent = 75;
    // 图形大小
    var sliceBorderWidth = 1;
    // Width (in pixels) of the border around each slice
    var sliceBorderStyle = "#fff";
    // Colour of the border around each slice
    var sliceGradientColour = "#ddd";
    // Colour to use for one end of the chart gradient
    var maxPullOutDistance = 25;
    // How far, in pixels, to pull slices out when clicked
    var pullOutFrameStep = 4;
    // How many pixels to move a slice with each animation frame
    var pullOutFrameInterval = 40;
    // 显示字体的距离
    var pullOutLabelPadding = 40;
    //显示字体的距离
    var pullOutLabelFont = " ";
    // Pull-out slice label font
    var pullOutValueFont = "";
    // Pull-out slice value font
    var pullOutValuePrefix = "$";
    // Pull-out slice value prefix
    var pullOutShadowColour = "rgba( 0, 0, 0, .5 )";
    // Colour to use for the pull-out slice shadow
    var pullOutShadowOffsetX = 5;
    // X-offset (in pixels) of the pull-out slice shadow
    var pullOutShadowOffsetY = 5;
    // Y-offset (in pixels) of the pull-out slice shadow
    var pullOutShadowBlur = 5;
    // How much to blur the pull-out slice shadow
    var pullOutBorderWidth = 2;
    // Width (in pixels) of the pull-out slice border
    var pullOutBorderStyle = "#333";
    // Colour of the pull-out slice border
    var chartStartAngle = -.5 * Math.PI;
    // Start the chart at 12 o'clock instead of 3 o'clock

    var canvas;
    // The canvas element in the page
    var currentPullOutSlice = -1;
    // The slice currently pulled out (-1 = no slice)
    var currentPullOutDistance = 0;
    // How many pixels the pulled-out slice is currently pulled out in the animation
    var animationId = 0;
    // Tracks the interval ID for the animation created by setInterval()
    var chartData = [];
    // Chart data (labels, values, and angles)
    var chartColours = [];
    // Chart colours (pulled from the HTML table)
    var totalValue = 0;
    // Total of all the values in the chart
    var canvasWidth;
    // Width of the canvas, in pixels
    var canvasHeight;
    // Height of the canvas, in pixels
    var centreX;
    // X-coordinate of centre of the canvas/chart
    var centreY;
    // Y-coordinate of centre of the canvas/chart
    var chartRadius;
    // Radius of the pie chart, in pixels
    init();
    function init() {
        canvas = document.getElementById('chart');
        if ( typeof canvas.getContext === 'undefined')
            return;
        canvasWidth = canvas.width;
        canvasHeight = canvas.height;
        centreX = canvasWidth / 2;
        centreY = canvasHeight / 2;
        chartRadius = Math.min(canvasWidth, canvasHeight) / 2 * (chartSizePercent / 100);

        var currentRow = -1;
        var currentCell = 0;

        $('#chartData td').each(function() {
            if ($(this).attr("flag") == "true") {
            currentCell++;
                if (currentCell % 2 != 0) {
                    currentRow++;
                    chartData[currentRow] = [];
                    chartData[currentRow]['label'] = $(this).text();
                } else {
                    var value = parseFloat($(this).text());
                    totalValue += value;
                    value = value.toFixed(2);
                    chartData[currentRow]['value'] = value;
                }

                $(this).data('slice', currentRow);

                if ( rgb = $(this).css('color').match(/rgb\((\d+), (\d+), (\d+)/)) {
                    chartColours[currentRow] = [rgb[1], rgb[2], rgb[3]];
                } else if ( hex = $(this).css('color').match(/#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/)) {
                    chartColours[currentRow] = [parseInt(hex[1], 16), parseInt(hex[2], 16), parseInt(hex[3], 16)];
                } else {
                    alert("Error: Colour could not be determined! Please specify table colours using the format '#xxxxxx'");
                    return;
                }
            };

        });
        var currentPos = 0;
        for (var slice in chartData) {
            chartData[slice]['startAngle'] = 2 * Math.PI * currentPos;
            chartData[slice]['endAngle'] = 2 * Math.PI * (currentPos + (chartData[slice]['value'] / totalValue));
            currentPos += chartData[slice]['value'] / totalValue;
        }

        drawChart();
    }

    function handleTableClick(clickEvent) {
        var slice = $(this).data('slice');
        toggleSlice(slice);
    }

    function toggleSlice(slice) {
        if (slice == currentPullOutSlice) {
            pushIn();
        } else {
            startPullOut(slice);
        }
    }

    function startPullOut(slice) {
        if (currentPullOutSlice == slice)
            return;
        currentPullOutSlice = slice;
        currentPullOutDistance = 0;
        clearInterval(animationId);
        animationId = setInterval(function() {
            animatePullOut(slice);
        }, pullOutFrameInterval);
        $('#chartData td').removeClass('highlight');
        var labelCell = $('#chartData td:eq(' + (slice * 2) + ')');
        var valueCell = $('#chartData td:eq(' + (slice * 2 + 1) + ')');
        labelCell.addClass('highlight');
        valueCell.addClass('highlight');
    }

    function animatePullOut(slice) {
        currentPullOutDistance += pullOutFrameStep;
        if (currentPullOutDistance >= maxPullOutDistance) {
            clearInterval(animationId);
            return;
        }
        drawChart();
    }

    function drawChart() {
        var context = canvas.getContext('2d');
        context.clearRect(0, 0, canvasWidth, canvasHeight);
        for (var slice in chartData) {
            if (slice != currentPullOutSlice)
                drawSlice(context, slice);
        }
        if (currentPullOutSlice != -1)
            drawSlice(context, currentPullOutSlice);
    }

    function drawSlice(context, slice) {
        var startAngle = chartData[slice]['startAngle'] + chartStartAngle;
        var endAngle = chartData[slice]['endAngle'] + chartStartAngle;

        if (slice == currentPullOutSlice) {
            var midAngle = (startAngle + endAngle) / 2;
            var actualPullOutDistance = currentPullOutDistance * easeOut(currentPullOutDistance / maxPullOutDistance, .8);
            startX = centreX + Math.cos(midAngle) * actualPullOutDistance;
            startY = centreY + Math.sin(midAngle) * actualPullOutDistance;
            context.fillStyle = 'rgb(' + chartColours[slice].join(',') + ')';
            context.textAlign = "center";
            context.font = pullOutLabelFont;
            context.fillText(chartData[slice]['label'], centreX + Math.cos(midAngle) * (chartRadius + maxPullOutDistance + pullOutLabelPadding), centreY + Math.sin(midAngle) * (chartRadius + maxPullOutDistance + pullOutLabelPadding));
            context.font = pullOutValueFont;
            context.fillText(pullOutValuePrefix + chartData[slice]['value'] + " (" + (parseInt(chartData[slice]['value'] / totalValue * 100 + .5)) + "%)", centreX + Math.cos(midAngle) * (chartRadius + maxPullOutDistance + pullOutLabelPadding), centreY + Math.sin(midAngle) * (chartRadius + maxPullOutDistance + pullOutLabelPadding) + 20);
            context.shadowOffsetX = pullOutShadowOffsetX;
            context.shadowOffsetY = pullOutShadowOffsetY;
            context.shadowBlur = pullOutShadowBlur;

        } else {
            startX = centreX;
            startY = centreY;
        }
        var sliceGradient = context.createLinearGradient(0, 0, canvasWidth * .75, canvasHeight * .75);
        sliceGradient.addColorStop(0, sliceGradientColour);
        sliceGradient.addColorStop(1, 'rgb(' + chartColours[slice].join(',') + ')');

        context.beginPath();
        context.moveTo(startX, startY);
        context.arc(startX, startY, chartRadius, startAngle, endAngle, false);
        context.lineTo(startX, startY);
        context.closePath();
        context.fillStyle = sliceGradient;
        context.shadowColor = (slice == currentPullOutSlice) ? pullOutShadowColour : "rgba( 0, 0, 0, 0 )";
        context.fill();
        context.shadowColor = "rgba( 0, 0, 0, 0 )";
        if (slice == currentPullOutSlice) {
            context.lineWidth = pullOutBorderWidth;
            context.strokeStyle = pullOutBorderStyle;
        } else {
            context.lineWidth = sliceBorderWidth;
            context.strokeStyle = sliceBorderStyle;
        }
        context.stroke();
    }

    function easeOut(ratio, power) {
        return (Math.pow(1 - ratio, power) + 1);
    }

};
